@@ -1,6 +1,6 @@
 //! Types and utilities for manipulating the Wayland protocol
 
-use std::{ffi::CString, os::unix::prelude::AsRawFd};
+use std::{ffi::CString, os::unix::io::AsRawFd};
 
 pub use wayland_sys::common::{wl_argument, wl_interface, wl_message};
 
@@ -121,16 +121,16 @@ impl<Id: PartialEq, Fd: AsRawFd> PartialEq for Argument<Id, Fd> {
 impl<Id: Eq, Fd: AsRawFd> Eq for Argument<Id, Fd> {}
 
 impl<Id: std::fmt::Display, Fd: AsRawFd> std::fmt::Display for Argument<Id, Fd> {
-    #[cfg_attr(coverage, coverage(off))]
+    #[cfg_attr(unstable_coverage, coverage(off))]
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         match self {
-            Self::Int(value) => write!(f, "{}", value),
-            Self::Uint(value) => write!(f, "{}", value),
-            Self::Fixed(value) => write!(f, "{}", value),
-            Self::Str(value) => write!(f, "{:?}", value),
-            Self::Object(value) => write!(f, "{}", value),
-            Self::NewId(value) => write!(f, "{}", value),
-            Self::Array(value) => write!(f, "{:?}", value),
+            Self::Int(value) => write!(f, "{value}"),
+            Self::Uint(value) => write!(f, "{value}"),
+            Self::Fixed(value) => write!(f, "{:.4}", *value as f64 / 256.0),
+            Self::Str(value) => write!(f, "{value:?}"),
+            Self::Object(value) => write!(f, "{value}"),
+            Self::NewId(value) => write!(f, "{value}"),
+            Self::Array(value) => write!(f, "{value:?}"),
             Self::Fd(value) => write!(f, "{}", value.as_raw_fd()),
         }
     }
@@ -155,7 +155,7 @@ pub struct Interface {
 }
 
 impl std::fmt::Display for Interface {
-    #[cfg_attr(coverage, coverage(off))]
+    #[cfg_attr(unstable_coverage, coverage(off))]
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         f.write_str(self.name)
     }
@@ -254,7 +254,7 @@ impl<Id: Eq, Fd: AsRawFd> Eq for Message<Id, Fd> {}
 impl std::error::Error for ProtocolError {}
 
 impl std::fmt::Display for ProtocolError {
-    #[cfg_attr(coverage, coverage(off))]
+    #[cfg_attr(unstable_coverage, coverage(off))]
     fn fmt(&self, f: &mut ::std::fmt::Formatter) -> Result<(), ::std::fmt::Error> {
         write!(
             f,
