@@ -20,7 +20,7 @@ pub enum MessageWriteError {
 impl std::error::Error for MessageWriteError {}
 
 impl std::fmt::Display for MessageWriteError {
-    #[cfg_attr(coverage, coverage(off))]
+    #[cfg_attr(unstable_coverage, coverage(off))]
     fn fmt(&self, f: &mut ::std::fmt::Formatter) -> Result<(), ::std::fmt::Error> {
         match self {
             Self::BufferTooSmall => {
@@ -29,8 +29,7 @@ impl std::fmt::Display for MessageWriteError {
             Self::DupFdFailed(e) => {
                 write!(
                     f,
-                    "The message contains a file descriptor that could not be dup()-ed ({}).",
-                    e
+                    "The message contains a file descriptor that could not be dup()-ed ({e})."
                 )
             }
         }
@@ -51,7 +50,7 @@ pub enum MessageParseError {
 impl std::error::Error for MessageParseError {}
 
 impl std::fmt::Display for MessageParseError {
-    #[cfg_attr(coverage, coverage(off))]
+    #[cfg_attr(unstable_coverage, coverage(off))]
     fn fmt(&self, f: &mut ::std::fmt::Formatter) -> Result<(), ::std::fmt::Error> {
         match *self {
             Self::MissingFD => {
