@@ -43,7 +43,7 @@ pub trait ObjectData<D>: downcast_rs::DowncastSync {
     /// Helper for forwarding a Debug implementation of your `ObjectData` type
     ///
     /// By default will just print `ObjectData { ... }`
-    #[cfg_attr(coverage, coverage(off))]
+    #[cfg_attr(unstable_coverage, coverage(off))]
     fn debug(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         f.debug_struct("ObjectData").finish_non_exhaustive()
     }
@@ -52,7 +52,7 @@ pub trait ObjectData<D>: downcast_rs::DowncastSync {
 downcast_rs::impl_downcast!(sync ObjectData<D>);
 
 impl<D: 'static> std::fmt::Debug for dyn ObjectData<D> {
-    #[cfg_attr(coverage, coverage(off))]
+    #[cfg_attr(unstable_coverage, coverage(off))]
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         self.debug(f)
     }
@@ -91,14 +91,14 @@ pub trait GlobalHandler<D>: downcast_rs::DowncastSync {
     /// Helper for forwarding a Debug implementation of your `GlobalHandler` type
     ///
     /// By default will just print `GlobalHandler { ... }`
-    #[cfg_attr(coverage, coverage(off))]
+    #[cfg_attr(unstable_coverage, coverage(off))]
     fn debug(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         f.debug_struct("GlobalHandler").finish_non_exhaustive()
     }
 }
 
 impl<D: 'static> std::fmt::Debug for dyn GlobalHandler<D> {
-    #[cfg_attr(coverage, coverage(off))]
+    #[cfg_attr(unstable_coverage, coverage(off))]
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         self.debug(f)
     }
@@ -115,14 +115,14 @@ pub trait ClientData: downcast_rs::DowncastSync {
     /// Helper for forwarding a Debug implementation of your `ClientData` type
     ///
     /// By default will just print `GlobalHandler { ... }`
-    #[cfg_attr(coverage, coverage(off))]
+    #[cfg_attr(unstable_coverage, coverage(off))]
     fn debug(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         f.debug_struct("ClientData").finish_non_exhaustive()
     }
 }
 
 impl std::fmt::Debug for dyn ClientData {
-    #[cfg_attr(coverage, coverage(off))]
+    #[cfg_attr(unstable_coverage, coverage(off))]
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         self.debug(f)
     }
@@ -185,14 +185,14 @@ impl ObjectId {
 }
 
 impl fmt::Display for ObjectId {
-    #[cfg_attr(coverage, coverage(off))]
+    #[cfg_attr(unstable_coverage, coverage(off))]
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         self.id.fmt(f)
     }
 }
 
 impl fmt::Debug for ObjectId {
-    #[cfg_attr(coverage, coverage(off))]
+    #[cfg_attr(unstable_coverage, coverage(off))]
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         self.id.fmt(f)
     }
@@ -209,7 +209,7 @@ pub struct ClientId {
 }
 
 impl fmt::Debug for ClientId {
-    #[cfg_attr(coverage, coverage(off))]
+    #[cfg_attr(unstable_coverage, coverage(off))]
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         self.id.fmt(f)
     }
@@ -222,7 +222,7 @@ pub struct GlobalId {
 }
 
 impl fmt::Debug for GlobalId {
-    #[cfg_attr(coverage, coverage(off))]
+    #[cfg_attr(unstable_coverage, coverage(off))]
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         self.id.fmt(f)
     }
@@ -539,7 +539,7 @@ impl<D> Backend<D> {
     ///
     /// The file descriptor should not be used for any other purpose than monitoring it.
     #[inline]
-    pub fn poll_fd(&self) -> BorrowedFd {
+    pub fn poll_fd(&self) -> BorrowedFd<'_> {
         self.backend.poll_fd()
     }
 
@@ -587,7 +587,7 @@ pub(crate) struct DumbObjectData;
 
 #[allow(dead_code)]
 impl<D> ObjectData<D> for DumbObjectData {
-    #[cfg_attr(coverage, coverage(off))]
+    #[cfg_attr(unstable_coverage, coverage(off))]
     fn request(
         self: Arc<Self>,
         _handle: &Handle,
@@ -598,7 +598,7 @@ impl<D> ObjectData<D> for DumbObjectData {
         unreachable!()
     }
 
-    #[cfg_attr(coverage, coverage(off))]
+    #[cfg_attr(unstable_coverage, coverage(off))]
     fn destroyed(
         self: Arc<Self>,
         _handle: &Handle,
